@@ -4,6 +4,7 @@
 import unittest
 from splitpatch.tree import DirNode, FileDiff
 from splitpatch.merge import Merge
+from splitpatch import logger
 
 class TestMerge(unittest.TestCase):
     def setUp(self):
@@ -36,7 +37,7 @@ class TestMerge(unittest.TestCase):
         self.dir5_sub_sub = next(node for node in self.dir5_sub.dir_nodes if node.name == "dir5_sub_sub")
 
         # Create MergeStrategy instance
-        self.merge_strategy = Merge(self.root, level=0, threshold=2)
+        self.merge_strategy = Merge(self.root, level=1, threshold=2)
 
     def test_merge(self):
         """Test merge strategy"""
@@ -118,5 +119,28 @@ class TestMerge(unittest.TestCase):
                 actual_files.add(file_node.path)
         self.assertEqual(actual_files, expected_files)
 
+    def test_verify_tree_integrity(self):
+        """Test tree integrity verification"""
+        # Enable debug mode
+        original_debug = logger.is_debug_mode()
+        logger.set_debug_mode(True)
+        try:
+            # Test normal case
+            self.merge_strategy._verify_tree_integrity(self.root)
+
+            # Test invalid parent reference
+            self.dir1_sub.parent = self.dir2
+            with self.assertRaises(ValueError):
+                self.merge_strategy._verify_tree_integrity(self.root)
+
+            # Test invalid file path
+            self.dir1_sub.parent = self.dir1  # Reset parent
+            self.dir1.file_changes[0].path = "invalid/path/file.txt"
+            with self.assertRaises(ValueError):
+                self.merge_strategy._verify_tree_integrity(self.root)
+        finally:
+            # Restore original debug mode
+            logger.set_debug_mode(original_debug)
+
 if __name__ == "__main__":
     unittest.main()
\ No newline at end of file
